pub struct MouseWheel {
pub delta: Vec2,
pub position: Vec2,
}Expand description
Mouse-wheel scroll event. delta is in logical pixels (positive y scrolls content down).
Backends normalise line-based wheel input to pixels with a fixed 32 px/line.
Fields
delta: Vec2Scroll delta in logical pixels.
position: Vec2Cursor position at the moment of the scroll, used for hit-testing.